@@ -25,6 +25,10 @@ import pandas as pd
 import simmer.sky as sky
 
 
+# Before we get into testing, there are a few utility functions
+# that'll be used.
+
+
 def download_folder(folder, path=None):
     """
     Downloads a .zip file from this projects S3 testing bucket, unzips it,
@@ -45,6 +49,7 @@ def download_folder(folder, path=None):
         "shane_quickstart": "q6m6ls2x2186u3p",
         "readpharo_test": "l8fi3100v5flufp",
         "config_test": "q0vqvy1ejd6rn14",
+        "search_headers": "7q20lgxae5yb3bz",
     }
 
     def retrieve_extract(path):
@@ -68,6 +73,15 @@ def download_folder(folder, path=None):
 
 
 def delete_folder(folder):
+    """
+    Delete a folder when needed.
+
+    Inputs:
+        :folder: (str) path to folder to be deleted.
+    """
+    if not os.path.exists(folder):
+        print("Nothing to delete.")
+        return
     if os.listdir(folder):
         for f in os.listdir(folder):
             if folder[-1] == "/":
@@ -87,6 +101,38 @@ class DataDownloadException(Exception):
     pass
 
 
+# TESTS BEGIN
+
+
+class TestExceptions(unittest.TestCase):
+    """
+    There are a few custom exceptions that are
+    intended to make the user experience a bit cleaner.
+    Here, we'll test that that they are thrown when
+    intended.
+    """
+
+    def test_flat_not_fits(self):
+        wrong_file_type = "4242.yml"
+        with self.assertRaises(image.FlatOpeningError):
+            image.open_flats(wrong_file_type)
+
+    def test_flat_non_existent(self):
+        non_existent_flat = "4242.fits"
+        with self.assertRaises(image.FlatOpeningError):
+            image.open_flats(non_existent_flat)
+
+    def test_dark_not_fits(self):
+        wrong_file_type = "4242.yml"
+        with self.assertRaises(flats.DarkOpeningError):
+            flats.open_darks(wrong_file_type)
+
+    def test_dark_non_existent(self):
+        non_existent_flat = "4242.fits"
+        with self.assertRaises(flats.DarkOpeningError):
+            flats.open_darks(non_existent_flat)
+
+
 class TestCreation(unittest.TestCase):
 
     inst = i.ShARCS()
